@@ -12,13 +12,37 @@ sub name_sep { q(.) }
 
 sub _build_type_map {
    +{
-      date => 'datetime',
-      'time' => 'datetime',
+      set   => 'varchar',
+      bytea => 'blob',
    }
 }
 
-sub _build_sizeless_types { +{ text => 1 } }
-sub _build_numeric_types { +{ int => 1, tinyint => 1 } }
+sub _build_sizeless_types {
+   +{
+      text => 1,
+      blob => 1,
+   }
+}
+sub _build_numeric_types {
+   +{
+      int                => 1,
+      integer            => 1,
+      tinyint            => 1,
+      smallint           => 1,
+      mediumint          => 1,
+      bigint             => 1,
+      'unsigned big int' => 1,
+      int2               => 1,
+      int8               => 1,
+      numeric            => 1,
+      decimal            => 1,
+      boolean            => 1,
+      real               => 1,
+      double             => 1,
+      'double precision' => 1,
+      float              => 1,
+   }
+}
 
 sub _build_unquoted_defaults {
    +{
@@ -54,7 +78,11 @@ sub field {
          : ( $self->field_type($field) )
       ),
       $self->field_nullable($field),
-      $self->field_default($field),
+      $self->field_default($field, {
+         NULL => 1,
+         'now()' => 1,
+         'CURRENT_TIMESTAMP' => 1,
+      }),
 }
 
 1;
